unit Tips;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, FormTips, Registry;

type
  TLanguage = (laEnglish, laGerman, laPortugues);
  TTips = class(TComponent)
  private
    FAppName : String;
    FHeader : String;
    FTipHelp : String;
    FTitle : String;
    FSaveKey : String;
    FShowAtStart : Boolean;
    FSaveShowAtStart : Boolean;
    FTips : TStringList;
    FLanguage : Tlanguage;
    FBackColor : TColor;
    function GetTipsCount: word;
    procedure SetTips(Value : TStringList);
  protected
  public
    constructor Create(AOwner:TComponent);override;
    destructor Destroy;override;
    Function Execute : boolean;
    procedure SaveToRegistry(Value : Boolean);
    function LoadFromRegistry: Boolean;
  published
    Property AppName : string read FAppName write FAppName;
    Property SaveShowAtStart : Boolean read FSaveShowAtStart write FSaveShowAtStart;
    Property SaveKey : String read FSaveKey write FSaveKey;
    Property Language : TLanguage read FLanguage write FLanguage;
    Property TipBackground : TColor read FBackColor write FBackColor;
    Property Header : string read FHeader write FHeader;
    Property Title : string read FTitle write FTitle;
    Property TipHelp : string read FTipHelp write FTipHelp;
    Property ShowAtStart : boolean read FShowAtStart write FShowAtStart;
    Property Tips : TStringList read FTips write SetTips;
    Property TipsCount : word read GetTipsCount;
end;

Var
  TipsDlg : TTipForm;
  Reg : TRegistry;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('Dialogs',[TTIPS]);
end;

constructor TTips.Create(AOwner:TComponent);
begin
  inherited Create(AOwner);
  FTips := TStringList.Create;
end;

destructor TTips.Destroy;
begin
  FTips.Free;
  inherited Destroy;
end;

procedure TTips.SetTips(Value:TStringList);
begin
  If FTips <> Value then
    FTips.Assign( Value )
end;

function TTips.GetTipsCount:Word;
begin
  Result := Tips.Count;
end;

procedure TTips.SaveToRegistry(Value : Boolean);
begin
  if FSaveShowAtStart then begin
    Try
      Reg:= TRegistry.Create;
      Reg.RootKey:= HKEY_CURRENT_USER;
      Reg.OpenKey(FSaveKey, True);
      Reg.WriteBool('ShowAtStart', Value);
    Finally
      Reg.Free;
    End;
end;

end;

function TTips.LoadFromRegistry : Boolean;
begin
  Try
    Reg:= TRegistry.Create;
    Reg.RootKey:= HKEY_CURRENT_USER;
    Reg.OpenKey(FSaveKey, False);
    if Reg.ValueExists('ShowAtStart') then
      Result:= Reg.ReadBool('ShowAtStart')
    else
      Result:= FShowAtStart;
  Finally
    Reg.Free;
  End;
end;

function TTips.Execute: Boolean;
begin
  TipsDlg := TTipForm.Create(Application);
  TipsDlg.Caption := Title;
  TipsDlg.Header.Caption:= FHeader;
  with TipsDlg.ShowAtStart do
    if FAppName <> '' then
    begin
      case FLanguage of
       laEnglish  : Caption := '&Show this dialog on next Start of '+ FAppName;
       laGerman   : Caption := Format('&Beim nchsten Start von %s zeigen', [FAppName]);
       laPortugues: Caption := '&Mostra essa janela na prxima vez que iniciar '+ FAppName;
      end;
    end
    else
    begin
      case FLanguage of
        laEnglish  : Caption := '&Show this dialog on next Start';
        laGerman   : Caption := '&Dieses Dialogfeld beim nchsten Start zeigen';
        laPortugues: Caption := '&Mostra essa janela na prxima vez que iniciar';
      end;
    end;
  // ***
  case FLanguage of
    laEnglish :
      begin
        TipsDlg.Next.Caption:= '&Next >';
        TipsDlg.CloseBtn.Caption:= '&Close';
      end;
    laGerman:
      begin
        TipsDlg.Next.Caption:= '&Nchster >';
        TipsDlg.CloseBtn.Caption:= '&Schlieen';
      end;
    laPortugues:
      begin
        TipsDlg.Next.Caption:= '&Prxima >';
        TipsDlg.CloseBtn.Caption:= '&Fechar';
      end;
  end;
  // ***
  TipsDlg.TipHelp.Caption := TipHelp;
  TipsDlg.Panel1.Color:= FBackColor;
  TipsDlg.ShowAtStart.Checked := LoadFromRegistry;
  TipsDlg.TipText.Caption := '';
  TipsDlg.Tips.Assign(Tips);
  With TipsDlg do
    Result := (ShowModal <> 0);
  ShowAtStart := TipsDlg.ShowAtStart.Checked;
  SaveToRegistry(ShowAtStart);
  TipsDlg.Free;
end;

end.

